@@ -3,6 +3,7 @@ from braintree.add_on_gateway import AddOnGateway
 from braintree.address import Address
 from braintree.address_gateway import AddressGateway
 from braintree.braintree_gateway import BraintreeGateway
+from braintree.client_token import ClientToken
 from braintree.configuration import Configuration
 from braintree.credit_card import CreditCard
 from braintree.credit_card_gateway import CreditCardGateway
@@ -23,6 +24,10 @@ from braintree.merchant_account.business_details import BusinessDetails
 from braintree.merchant_account.funding_details import FundingDetails
 from braintree.merchant_account.individual_details import IndividualDetails
 from braintree.merchant_account_gateway import MerchantAccountGateway
+from braintree.payment_method import PaymentMethod
+from braintree.unknown_payment_method import UnknownPaymentMethod
+from braintree.payment_instrument_type import PaymentInstrumentType
+from braintree.paypal_account import PayPalAccount
 from braintree.partner_merchant import PartnerMerchant
 from braintree.plan import Plan
 from braintree.plan_gateway import PlanGateway
@@ -32,9 +37,11 @@ from braintree.settlement_batch_summary import SettlementBatchSummary
 from braintree.subscription import Subscription
 from braintree.subscription_gateway import SubscriptionGateway
 from braintree.status_event import StatusEvent
+from braintree.testing_gateway import TestingGateway
 from braintree.transaction import Transaction
 from braintree.transaction_gateway import TransactionGateway
 from braintree.transaction_search import TransactionSearch
+from braintree.signature_service import SignatureService
 from braintree.disbursement import Disbursement
 from braintree.subscription_search import SubscriptionSearch
 from braintree.successful_result import SuccessfulResult
@@ -47,3 +54,4 @@ from braintree.webhook_notification import WebhookNotification
 from braintree.webhook_notification_gateway import WebhookNotificationGateway
 from braintree.webhook_testing import WebhookTesting
 from braintree.webhook_testing_gateway import WebhookTestingGateway
+from braintree.sepa_bank_account import SEPABankAccount
